@@ -22,6 +22,7 @@
  * USA
  */
 
+#include "gchempaint-config.h"
 #include "electron.h"
 #include "atom.h"
 #include "document.h"
@@ -31,7 +32,7 @@
 #include "widgetdata.h"
 #include "libgcpcanvas/gcp-canvas-rect-ellipse.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
-#include <math.h>
+#include <cmath>
 
 #define POSITION_NE 1
 #define POSITION_NW 2
@@ -55,6 +56,10 @@ gcpElectron::gcpElectron (gcpAtom *pAtom, bool IsPair): Object ()
 
 gcpElectron::~gcpElectron ()
 {
+	if (m_pAtom && (GetParent () == m_pAtom))
+		// If not, this destructor is called from the Atom destructor and nothing should
+		// be done in that case.
+		m_pAtom->RemoveElectron (this);
 }
 
 char gcpElectron::GetPosition (double *angle, double *distance)
@@ -224,7 +229,7 @@ void gcpElectron::SetSelected(GtkWidget* w, int state)
 	
 	switch (state) {	
 	case SelStateUnselected:
-		color = "black";
+		color = (char*) "black";
 		break;
 	case SelStateSelected:
 		color = SelectColor;
@@ -236,7 +241,7 @@ void gcpElectron::SetSelected(GtkWidget* w, int state)
 		color = DeleteColor;
 		break;
 	default:
-		color = "black";
+		color = (char*) "black";
 		break;
 	}
 	g_object_set (G_OBJECT(g_object_get_data(G_OBJECT(group), "0")),
@@ -253,31 +258,31 @@ xmlNodePtr gcpElectron::Save (xmlDocPtr xml)
 	if (m_Pos) {
 		switch (m_Pos) {
 		case POSITION_NE:
-			buf = "ne";
+			buf = (char*) "ne";
 			break;
 		case POSITION_NW:
-			buf = "nw";
+			buf = (char*) "nw";
 			break;
 		case POSITION_N:
-			buf = "n";
+			buf = (char*) "n";
 			break;
 		case POSITION_SE:
-			buf = "se";
+			buf = (char*) "se";
 			break;
 		case POSITION_SW:
-			buf = "sw";
+			buf = (char*) "sw";
 			break;
 		case POSITION_S:
-			buf = "s";
+			buf = (char*) "s";
 			break;
 		case POSITION_E:
-			buf = "e";
+			buf = (char*) "e";
 			break;
 		case POSITION_W:
-			buf = "w";
+			buf = (char*) "w";
 			break;
 		default:
-			buf = "def"; // should not occur
+			buf = (char*) "def"; // should not occur
 		}
 		xmlNewProp (node, (xmlChar*) "position", (xmlChar*) buf);
 	} else {
