@@ -31,12 +31,12 @@
 #include "mesomery-arrow.h"
 #include "mesomer.h"
 #include <glib/gi18n-lib.h>
-#include <math.h>
+#include <cmath>
 #include <set>
 
 gcpMesomery::gcpMesomery (): Object (MesomeryType)
 {
-	SetId ("msy1");
+	SetId ((char*) "msy1");
 }
 
 gcpMesomery::~gcpMesomery ()
@@ -738,7 +738,7 @@ static void do_destroy_mesomery (void *data)
 	pDoc->FinishOperation ();
 }
 
-bool gcpMesomery::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
+bool gcpMesomery::BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y)
 {
 	GtkActionGroup *group = gtk_action_group_new ("mesomery");
 	GtkAction *action = gtk_action_new ("destroy-ms", _("Destroy the mesomery relationship"), NULL, NULL);
@@ -748,13 +748,13 @@ bool gcpMesomery::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
 	gtk_ui_manager_add_ui_from_string (UIManager, buf, -1, NULL);
 	GtkWidget *w = gtk_ui_manager_get_widget (UIManager, "/popup/destroy-ms");
 	g_signal_connect_swapped (w, "activate", G_CALLBACK (do_destroy_mesomery), this);
-	GetParent ()->BuildContextualMenu (UIManager, object);
+	GetParent ()->BuildContextualMenu (UIManager, object, x, y);
 	return true;
 }
 
 gcpMesomery::gcpMesomery (Object* parent, gcpMesomer *mesomer): Object (MesomeryType)
 {
-	SetId ("msy1");
+	SetId ((char*) "msy1");
 	SetParent (parent);
 	AddChild (mesomer);
 	set<Object *> Objects;
