@@ -36,13 +36,13 @@
 #include "libgcpcanvas/gcp-canvas-group.h"
 #include <libgnomevfs/gnome-vfs-file-info.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
-#include <math.h>
 #include <unistd.h>
 #include <pango/pango-context.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n-lib.h>
 #include <libgnomeprint/gnome-print-job.h>
-#include <locale.h>
+#include <cmath>
+#include <clocale>
 #ifdef HAVE_FSTREAM
 #	include <fstream>
 #else
@@ -286,7 +286,7 @@ bool gcpView::OnEvent(GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget)
 			 	m_UIManager = gtk_ui_manager_new ();
 				result = pActiveTool->OnRightButtonClicked(this, Obj, event->button.x, event->button.y, m_UIManager);
 				if (Obj)
-					result |= Obj->BuildContextualMenu (m_UIManager, Obj);
+					result |= Obj->BuildContextualMenu (m_UIManager, Obj, x / GetZoomFactor (), y / GetZoomFactor ());
 				if (result) {
 					GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager, "/popup");
 					gtk_menu_popup (GTK_MENU (w), NULL, NULL, NULL, NULL, 3,  gtk_get_current_event_time ());
