@@ -4,7 +4,7 @@
  * GChemPaint text plugin
  * texttool.cc 
  *
- * Copyright (C) 2002-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -762,7 +762,7 @@ static const guint16 font_sizes[] = {
 
 GtkWidget *gcpTextTool::GetPropertyPage ()
 {
-	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint-unstable/ui/fontsel.glade", "fontsel", GETTEXT_PACKAGE);
+	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint/ui/fontsel.glade", "fontsel", GETTEXT_PACKAGE);
 	PangoFontFamily **families;
 	int i, nb;
 	gcpTheme *pTheme = m_pApp->GetActiveDocument ()->GetTheme ();
